/**
 * Function that needs to be exported for getting the LSB Size
 * arguments should be in the same order as it will be passed from the GUI
 * controlData   : Entire Object
 * parameters     : Parameters stored in the JSON file
 * common        : Common Controls in parameters JSON file
 * codeToVoltage : Code to Voltage Controls in parameters JSON file
 * voltageToCode : Voltage to Code Controls in parameters JSON file
 */

export function getLsbSize(
  controlData,
  parameters,
  common,
  codeToVoltage,
  voltageToCode,
) {
  return (
    getFsrValue(controlData, parameters, common, codeToVoltage, voltageToCode) /
    getNumOfCodesValue(parameters)
  );
}

/**
 * Function that needs to be exported for getting the FSR Value
 * arguments should be in the same order as it will be passed from the GUI
 * controlData   : Entire Object
 * parameters    : Parameters stored in the JSON file
 * common        : Common Controls in parameters JSON file
 * codeToVoltage : Code to Voltage Controls in parameters JSON file
 * voltageToCode : Voltage to Code Controls in parameters JSON file
 */

/**
 * parseFloat/parseInt is used to convert a string format into float/decimal
 */

export function getFsrValue(
  controlData,
  parameters,
  common,
  codeToVoltage,
  voltageToCode,
) {
  const refVoltage = parseFloat(common.refVoltage.value);
  const fsrMultiplier = parseInt(parameters.fsrMultiplier);
  const pgaGain = parseInt(common.pgaGain.value);
  return (refVoltage * fsrMultiplier) / pgaGain;
}

//Helper Functions
function getNumOfCodesValue(parameters) {
  const bitResolution = parseInt(parameters.resolution);
  return 2 ** bitResolution;
}
